<!--  -->
<template>
  <div class="boxleft">
    <title-box-vue :title="titleName">
      <template v-slot:right>
        <slot name="titleright"></slot>
      </template>
    </title-box-vue>
    <fks-select v-if="selectIsShow"
      v-model="selectvalue"
      @change="selectChange"
      placeholder="请选择"
    >
      <fks-option
        v-for="item in selectData"
        :key="item.value"
        :label="item.label"
        :value="item.value"
      >
      </fks-option>
    </fks-select>
    <fks-tree
      ref="tree"
      :data="treedata"
      :props="defaultProps"
      :show-icon="true"
      node-key="id"
      :current-node-key="currentNodeKey1"
      :default-expanded-keys="defaultExpandedKeys"
      :highlight-current="true"
      :filter-node-method="filterNode"
      @node-click="handleNodeClick"
    >
      <span class="custom-tree-node" slot-scope="{ node, data }">
        <span>{{ node.label }}</span>
        <span v-if="node.isLeaf&&isShowRightIcon">
          <fks-button
            type="text"
            size="mini"
            icon="fks-icon-edit"
            @click.stop="() => edit(data, node)"
          >
          </fks-button>
        </span>
      </span>
    </fks-tree>
  </div>
</template>

<script>
import titleBoxVue from "./titleBox.vue";

export default {
  name: "leftTree",
  components: { titleBoxVue },
  props: {
    treedata: {
      type: Array,
      default: () => {
        return [];
      },
      require: true,
    },
    selectData: {
      type: Array,
      default: () => {
        return [];
      },
      require: true,
    },
    selectIsShow:{
      type: Boolean,
      default: false,
    },
    defaultProps: {
      type: Object,
      default: () => {
        return {
          children: "children",
          label: "label",
        };
      },
    },
    currentNodeKey: {
      type: String,
      default: "",
    },
    defaultSelectValue: {
      type: String,
      default: "",
    },
    defaultExpandedKeys: {
      type: Array,
      default: () => {
        return [];
      },
    },
    titleName: {
      type: String,
      default: "功能位置",
    },
    isShowRightIcon:{
      type: Boolean,
      default: false,
    }
  },
  data() {
    return {
      filterText: "",
      selectvalue: "",
    };
  },
  created() {},
  mounted() {
    this.selectvalue = this.defaultSelectValue;
  },
  computed: {
    currentNodeKey1() {
      let key = this.currentNodeKey;
      if (this.treedata.length && key === "") {
        key = this.treedata[0].id;
      }
      return key;
    },
  },
  watch: {
    filterText(val) {
      this.$refs.tree.filter(val);
    },
  },
  methods: {
    edit(data, node) {
      // console.log(data, node, 122);
      this.$emit("treeEdit", data, node);
    },
    selectChange(value) {
      this.$emit("selectchange", value);
    },
    handleNodeClick(data) {
      //   console.log(data, 74);
      this.$emit("click", data);
    },
    filterNode(value, data) {
      if (!value) return true;
      return data.label.indexOf(value) !== -1;
    },
  },
};
</script>
<style scoped>
.boxleft {
  background-color: #fff;
  width:220px;
}

.custom-tree-node {
    flex: 1;
    display: flex;
    align-items: center;
    justify-content: space-between;
    font-size: 14px;
    padding-right: 8px;
  }
</style>


<style>
/* .custom-tree-node {
    flex: 1;
    display: flex;
    align-items: center;
    justify-content: space-between;
    font-size: 14px;
    padding-right: 8px;
  } */
</style>